==> cosmos_synthesizer-0.8.5b0.tar.gz: cosmos_synthesizer-0.8.5b0/src/synthesizer/utils/art.py <==
"""A module containing ASCII art for pretty outputs.

Example usage:

    from synthesizer.art import Art
    print(Art.galaxy)
"""


class Art:
    """
    A class containing art.
    """

    synthesizer = (
        "+-+-+-+-+-+-+-+-+-+-+-+\n"
        "|S|Y|N|T|H|E|S|I|Z|E|R|\n"
        "+-+-+-+-+-+-+-+-+-+-+-+\n"
    )

    galaxy2 = (
        "⠀⠀⠀⠀⠀⠀⠀⠀⠀⠀⢀⣀⣀⡀⠒⠒⠦⣄⡀⠀⠀⠀⠀⠀⠀⠀\n"
        "⠀⠀⠀⠀⠀⢀⣤⣶⡾⠿⠿⠿⠿⣿⣿⣶⣦⣄⠙⠷⣤⡀⠀⠀⠀⠀\n"
        "⠀⠀⠀⣠⡾⠛⠉⠀⠀⠀⠀⠀⠀⠀⠈⠙⠻⣿⣷⣄⠘⢿⡄⠀⠀⠀\n"
        "⠀⢀⡾⠋⠀⠀⠀⠀⠀⠀⠀⠀⠐⠂⠠⢄⡀⠈⢿⣿⣧⠈⢿⡄⠀⠀\n"
        "⢀⠏⠀⠀⠀⢀⠄⣀⣴⣾⠿⠛⠛⠛⠷⣦⡙⢦⠀⢻⣿⡆⠘⡇⠀⠀\n"
        "⠀⠀⠀⠀⡐⢁⣴⡿⠋⢀⠠⣠⠤⠒⠲⡜⣧⢸⠄⢸⣿⡇⠀⡇⠀⠀\n"
        "⠀⠀⠀⡼⠀⣾⡿⠁⣠⢃⡞⢁⢔⣆⠔⣰⠏⡼⠀⣸⣿⠃⢸⠃⠀⠀\n"
        "⠀⠀⢰⡇⢸⣿⡇⠀⡇⢸⡇⣇⣀⣠⠔⠫⠊⠀⣰⣿⠏⡠⠃⠀⠀⢀\n"
        "⠀⠀⢸⡇⠸⣿⣷⠀⢳⡈⢿⣦⣀⣀⣀⣠⣴⣾⠟⠁⠀⠀⠀⠀⢀⡎\n"
        "⠀⠀⠘⣷⠀⢻⣿⣧⠀⠙⠢⠌⢉⣛⠛⠋⠉⠀⠀⠀⠀⠀⠀⣠⠎⠀\n"
        "⠀⠀⠀⠹⣧⡀⠻⣿⣷⣄⡀⠀⠀⠀⠀⠀⠀⠀⠀⠀⢀⣠⡾⠃⠀⠀\n"
        "⠀⠀⠀⠀⠈⠻⣤⡈⠻⢿⣿⣷⣦⣤⣤⣤⣤⣤⣴⡾⠛⠉⠀⠀⠀⠀\n"
        "⠀⠀⠀⠀⠀⠀⠈⠙⠶⢤⣈⣉⠛⠛⠛⠛⠋⠉⠀⠀⠀⠀⠀⠀⠀⠀\n"
        "⠀⠀⠀⠀⠀⠀⠀⠀⠀⠀⠀⠀⠉⠉⠉⠁⠀⠀⠀⠀⠀⠀⠀⠀⠀⠀\n"
    )

    galaxy = (
        "⠀⠀⠀⠀⠀⠀⠀⠀⠀⠀⢀⣀⣀⡀⠒⠒⠦⣄⡀⠀⠀⠀⠀⠀⠀⠀\n"
        "⠀⠀⠀⠀⠀⢀⣤⣶⡾⠿⠿⠿⠿⣿⣿⣶⣦⣄⠙⠷⣤⡀⠀⠀⠀⠀\n"
        "⠀⠀⠀⣠⡾⠛⠉⠀⠀⠀⠀⠀⠀⠀⠈⠙⠻⣿⣷⣄⠘⢿⡄⠀⠀⠀\n"
        "⠀⢀⡾⠋⠀⠀⠀⠀⠀⠀⠀⠀⠐⠂⠠⢄⡀⠈⢿⣿⣧⠈⢿⡄⠀⠀\n"
        "⢀⠏⠀⠀⠀⢀⠄⣀⣴⣾⠿⠛⠛⠛⠷⣦⡙⢦⠀⢻⣿⡆⠘⡇⠀⠀\n"
        "⠀⠀⠀+-+-+-+-+-+-+-+-+-+-+-+⡇⠀⠀\n"
        "⠀⠀⠀|S|Y|N|T|H|E|S|I|Z|E|R|⠃⠀⠀\n"
        "⠀⠀⢰+-+-+-+-+-+-+-+-+-+-+-+⠀⠀⠀\n"
        "⠀⠀⢸⡇⠸⣿⣷⠀⢳⡈⢿⣦⣀⣀⣀⣠⣴⣾⠟⠁⠀⠀⠀⠀⢀⡎\n"
        "⠀⠀⠘⣷⠀⢻⣿⣧⠀⠙⠢⠌⢉⣛⠛⠋⠉⠀⠀⠀⠀⠀⠀⣠⠎⠀\n"
        "⠀⠀⠀⠹⣧⡀⠻⣿⣷⣄⡀⠀⠀⠀⠀⠀⠀⠀⠀⠀⢀⣠⡾⠃⠀⠀\n"
        "⠀⠀⠀⠀⠈⠻⣤⡈⠻⢿⣿⣷⣦⣤⣤⣤⣤⣤⣴⡾⠛⠉⠀⠀⠀⠀\n"
        "⠀⠀⠀⠀⠀⠀⠈⠙⠶⢤⣈⣉⠛⠛⠛⠛⠋⠉⠀⠀⠀⠀⠀⠀⠀⠀\n"
        "⠀⠀⠀⠀⠀⠀⠀⠀⠀⠀⠀⠀⠉⠉⠉⠁⠀⠀⠀⠀⠀⠀⠀⠀⠀⠀\n"
    )

    blackhole = (
        "                                                               \n"
        "                     ´```´``````````````´                      \n"
        "               `´```````````´´`´´¨´´```````````                \n"
        "           ````````````´¨¨···…………··¨¨¨´´``````````             \n"
        "        ```````````´¨··¸¸’‚:›‹¹¹‹;’‚˜¸…·¨¨´``````````          \n"
        "      `````````´´´¨·¸˜‘›º—!¿jo¤îï{•^³°;‚ˆ¸·¨¨´´````````        \n"
        "     ````````´´´¨·¸˜’­„¿‰uusssssöö¢u<«^³‹‘˜¸·¨¨´´´````````      \n"
        "    ````````´´¨··¸’;³(¤‰uò%ízí1It‰¢öösì)—º;’ˆ¸·¨¨´´```````     \n"
        "  ````````´´´¨·…¸‚›~7Issjƒ•÷¦—÷|)}l‰söö¼}÷~¹‘ˆ…·¨¨´´````````   \n"
        "  ``````´´¨··…˜’°~[c½òì%¡—„““”^÷«×=¢òö¢ƒ}÷³›’¸…·¨¨´````````    \n"
        " ```````´´¨··…’›~¡<ƒ‰s½>[•!÷÷¬«+¿†iíƒuòsöòƒì+„~“¹;’…´´```````  \n"
        " ````´˜’‚’|†1jlíj¤Jƒƒzƒtj=<>iiii>†×¿†77¿)!„–:’¸…·¨´´´```````   \n"
        "  ``````´´¨¨·…ˆ’;­“¯i¼c}>|¯ª””„^¦|)<l¢öì•^°:’¸…·¨¨´````````     \n"
        "   ```````´´¨·…¸˜‘¹“•‡¢‰¢[}!¦¦¦¡•×ƒ‰söc)^–:’¸…·¨¨´````````     \n"
        "    ```````´´´¨¨…¸˜:­„1½¢us½llïosòòss<¡~¹‘ˆ¸·¨´´´´``````        \n"
        "      ````````´´´¨…ˆ’’­”}o‰½¢su¢¢uI»¯º¹’˜¸…¨¨´´```````          \n"
        "        `````````´¨¨·¸ˆ‚‘›²~ª^^„“–¹;‘’¸…·¨´´`````````          \n"
        "          ```````````´¨¨·¸˜˜˜˜˜˜ˆ¸¸…·¨¨´´````````              \n"
        "               ```````````´´´´´´´´´```````````                 \n"
        "                ``´`´´`´``````````````´```                     \n"
        "                   `  `                                        \n"
        "                      ´                                        \n"
    )


def get_centred_art(art, width):
    """
    A function to print the art centred in a width.

    Args:
        art (str)
            The art to be centred.
        width (int)
            The number of characters in the region to centre within.

    Returns:
        string
            The Art.galaxy art centred within width.
    """

    # Split the line into individual lines
    split_art = art.split("\n")

    # Initialise the centred string
    new_string = ""

    # Loop over the art string centring each line
    for line in split_art:
        if "+" in line or "|" in line:
            new_string += line.center(width + 4) + "\n"
        else:
            new_string += line.center(width) + "\n"

    return new_string


def print_centred_art(art, width):
    """
    A function to print the art centred in a width.

    Args:
        width (int)
            The number of characters in the region to centre within.
    """

    # Get the centred art
    art = get_centred_art(art, width)

    print(art)


""

==> cosmos_synthesizer-0.9.2b0.tar.gz: cosmos_synthesizer-0.9.2b0/src/synthesizer/utils/art.py <==
"""A module containing ASCII art for pretty outputs.

Example usage:

    from synthesizer.art import Art
    print(Art.galaxy)
"""


class Art:
    """A class containing art."""

    synthesizer = (
        "+-+-+-+-+-+-+-+-+-+-+-+\n"
        "|S|Y|N|T|H|E|S|I|Z|E|R|\n"
        "+-+-+-+-+-+-+-+-+-+-+-+\n"
    )

    galaxy2 = (
        "⠀⠀⠀⠀⠀⠀⠀⠀⠀⠀⢀⣀⣀⡀⠒⠒⠦⣄⡀⠀⠀⠀⠀⠀⠀⠀\n"
        "⠀⠀⠀⠀⠀⢀⣤⣶⡾⠿⠿⠿⠿⣿⣿⣶⣦⣄⠙⠷⣤⡀⠀⠀⠀⠀\n"
        "⠀⠀⠀⣠⡾⠛⠉⠀⠀⠀⠀⠀⠀⠀⠈⠙⠻⣿⣷⣄⠘⢿⡄⠀⠀⠀\n"
        "⠀⢀⡾⠋⠀⠀⠀⠀⠀⠀⠀⠀⠐⠂⠠⢄⡀⠈⢿⣿⣧⠈⢿⡄⠀⠀\n"
        "⢀⠏⠀⠀⠀⢀⠄⣀⣴⣾⠿⠛⠛⠛⠷⣦⡙⢦⠀⢻⣿⡆⠘⡇⠀⠀\n"
        "⠀⠀⠀⠀⡐⢁⣴⡿⠋⢀⠠⣠⠤⠒⠲⡜⣧⢸⠄⢸⣿⡇⠀⡇⠀⠀\n"
        "⠀⠀⠀⡼⠀⣾⡿⠁⣠⢃⡞⢁⢔⣆⠔⣰⠏⡼⠀⣸⣿⠃⢸⠃⠀⠀\n"
        "⠀⠀⢰⡇⢸⣿⡇⠀⡇⢸⡇⣇⣀⣠⠔⠫⠊⠀⣰⣿⠏⡠⠃⠀⠀⢀\n"
        "⠀⠀⢸⡇⠸⣿⣷⠀⢳⡈⢿⣦⣀⣀⣀⣠⣴⣾⠟⠁⠀⠀⠀⠀⢀⡎\n"
        "⠀⠀⠘⣷⠀⢻⣿⣧⠀⠙⠢⠌⢉⣛⠛⠋⠉⠀⠀⠀⠀⠀⠀⣠⠎⠀\n"
        "⠀⠀⠀⠹⣧⡀⠻⣿⣷⣄⡀⠀⠀⠀⠀⠀⠀⠀⠀⠀⢀⣠⡾⠃⠀⠀\n"
        "⠀⠀⠀⠀⠈⠻⣤⡈⠻⢿⣿⣷⣦⣤⣤⣤⣤⣤⣴⡾⠛⠉⠀⠀⠀⠀\n"
        "⠀⠀⠀⠀⠀⠀⠈⠙⠶⢤⣈⣉⠛⠛⠛⠛⠋⠉⠀⠀⠀⠀⠀⠀⠀⠀\n"
        "⠀⠀⠀⠀⠀⠀⠀⠀⠀⠀⠀⠀⠉⠉⠉⠁⠀⠀⠀⠀⠀⠀⠀⠀⠀⠀\n"
    )

    galaxy = (
        "⠀⠀⠀⠀⠀⠀⠀⠀⠀⠀⢀⣀⣀⡀⠒⠒⠦⣄⡀⠀⠀⠀⠀⠀⠀⠀\n"
        "⠀⠀⠀⠀⠀⢀⣤⣶⡾⠿⠿⠿⠿⣿⣿⣶⣦⣄⠙⠷⣤⡀⠀⠀⠀⠀\n"
        "⠀⠀⠀⣠⡾⠛⠉⠀⠀⠀⠀⠀⠀⠀⠈⠙⠻⣿⣷⣄⠘⢿⡄⠀⠀⠀\n"
        "⠀⢀⡾⠋⠀⠀⠀⠀⠀⠀⠀⠀⠐⠂⠠⢄⡀⠈⢿⣿⣧⠈⢿⡄⠀⠀\n"
        "⢀⠏⠀⠀⠀⢀⠄⣀⣴⣾⠿⠛⠛⠛⠷⣦⡙⢦⠀⢻⣿⡆⠘⡇⠀⠀\n"
        "⠀⠀⠀+-+-+-+-+-+-+-+-+-+-+-+⡇⠀⠀\n"
        "⠀⠀⠀|S|Y|N|T|H|E|S|I|Z|E|R|⠃⠀⠀\n"
        "⠀⠀⢰+-+-+-+-+-+-+-+-+-+-+-+⠀⠀⠀\n"
        "⠀⠀⢸⡇⠸⣿⣷⠀⢳⡈⢿⣦⣀⣀⣀⣠⣴⣾⠟⠁⠀⠀⠀⠀⢀⡎\n"
        "⠀⠀⠘⣷⠀⢻⣿⣧⠀⠙⠢⠌⢉⣛⠛⠋⠉⠀⠀⠀⠀⠀⠀⣠⠎⠀\n"
        "⠀⠀⠀⠹⣧⡀⠻⣿⣷⣄⡀⠀⠀⠀⠀⠀⠀⠀⠀⠀⢀⣠⡾⠃⠀⠀\n"
        "⠀⠀⠀⠀⠈⠻⣤⡈⠻⢿⣿⣷⣦⣤⣤⣤⣤⣤⣴⡾⠛⠉⠀⠀⠀⠀\n"
        "⠀⠀⠀⠀⠀⠀⠈⠙⠶⢤⣈⣉⠛⠛⠛⠛⠋⠉⠀⠀⠀⠀⠀⠀⠀⠀\n"
        "⠀⠀⠀⠀⠀⠀⠀⠀⠀⠀⠀⠀⠉⠉⠉⠁⠀⠀⠀⠀⠀⠀⠀⠀⠀⠀\n"
    )

    blackhole = (
        "                                                               \n"
        "                     ´```´``````````````´                      \n"
        "               `´```````````´´`´´¨´´```````````                \n"
        "           ````````````´¨¨···…………··¨¨¨´´``````````             \n"
        "        ```````````´¨··¸¸’‚:›‹¹¹‹;’‚˜¸…·¨¨´``````````          \n"
        "      `````````´´´¨·¸˜‘›º—!¿jo¤îï{•^³°;‚ˆ¸·¨¨´´````````        \n"
        "     ````````´´´¨·¸˜’­„¿‰uusssssöö¢u<«^³‹‘˜¸·¨¨´´´````````      \n"
        "    ````````´´¨··¸’;³(¤‰uò%ízí1It‰¢öösì)—º;’ˆ¸·¨¨´´```````     \n"
        "  ````````´´´¨·…¸‚›~7Issjƒ•÷¦—÷|)}l‰söö¼}÷~¹‘ˆ…·¨¨´´````````   \n"
        "  ``````´´¨··…˜’°~[c½òì%¡—„““”^÷«×=¢òö¢ƒ}÷³›’¸…·¨¨´````````    \n"
        " ```````´´¨··…’›~¡<ƒ‰s½>[•!÷÷¬«+¿†iíƒuòsöòƒì+„~“¹;’…´´```````  \n"
        " ````´˜’‚’|†1jlíj¤Jƒƒzƒtj=<>iiii>†×¿†77¿)!„–:’¸…·¨´´´```````   \n"
        "  ``````´´¨¨·…ˆ’;­“¯i¼c}>|¯ª””„^¦|)<l¢öì•^°:’¸…·¨¨´````````     \n"
        "   ```````´´¨·…¸˜‘¹“•‡¢‰¢[}!¦¦¦¡•×ƒ‰söc)^–:’¸…·¨¨´````````     \n"
        "    ```````´´´¨¨…¸˜:­„1½¢us½llïosòòss<¡~¹‘ˆ¸·¨´´´´``````        \n"
        "      ````````´´´¨…ˆ’’­”}o‰½¢su¢¢uI»¯º¹’˜¸…¨¨´´```````          \n"
        "        `````````´¨¨·¸ˆ‚‘›²~ª^^„“–¹;‘’¸…·¨´´`````````          \n"
        "          ```````````´¨¨·¸˜˜˜˜˜˜ˆ¸¸…·¨¨´´````````              \n"
        "               ```````````´´´´´´´´´```````````                 \n"
        "                ``´`´´`´``````````````´```                     \n"
        "                   `  `                                        \n"
        "                      ´                                        \n"
    )


def get_centred_art(art: str, width: int) -> str:
    """Print the art centred in a width.

    Args:
        art (str):
            The art to be centred.
        width (int):
            The number of characters in the region to centre within.

    Returns:
        string
            The Art.galaxy art centred within width.
    """
    # Split the line into individual lines
    split_art = art.split("\n")

    # Initialise the centred string
    new_string = ""

    # Loop over the art string centring each line
    for line in split_art:
        if "+" in line or "|" in line:
            new_string += line.center(width + 4) + "\n"
        else:
            new_string += line.center(width) + "\n"

    return new_string


def print_centred_art(art: str, width: int) -> None:
    """Print the art centred in a width.

    Args:
        art (str):
            The art to be centred.
        width (int):
            The number of characters in the region to centre within.
    """
    # Get the centred art
    art = get_centred_art(art, width)

    print(art)
